/* Model solution for the task Triangulations
 * Author: Jakub Radoszewski
 * Date: 24.05.2007
 * Description: Counts all Catalan numbers from 3-rd to n-th.
 */

#include<cstdio>
#include<cctype>
#include<cmath>
#include<cstdlib>
#include<algorithm>
#include<vector>
#include<string>
#include<list>
#include<deque>
#include<map>
#include<set>
#include<queue>
#include<stack>
#include<utility>
#include<sstream>
#include<cstring>
using namespace std;

#define FOR(I,A,B) for(int I=(A);I<=(B);I++)
#define FORD(I,A,B) for(int I=(A);I>=(B);I--)
#define REP(I,N) for(int I=0;I<(N);I++)
#define ALL(X) (X).begin(),(X).end()
#define PB push_back
#define MP make_pair
#define FI first
#define SE second
#define INFTY 100000000
#define VAR(V,init) __typeof(init) V=(init)
#define FOREACH(I,C) for(VAR(I,(C).begin());I!=(C).end();I++)

typedef vector<int> VI;
typedef pair<int,int> PII;
typedef long long ll;
typedef vector<string> VS;

ll nwd(ll a,ll b) { return !b?a:nwd(b,a%b); }
inline int CEIL(int a,int b) { return a%b ? a/b+1 : a/b; }
template <class T> inline T sqr(const T&a) { return a*a; }

#define MAX_N 100000

int n,m;

int pr; /* number of interesting primes */
int prime[2*MAX_N+1]; /* 0-not prime, >0 - prime (with its number) */
int factor[2*MAX_N+1]; /* prime factors of numbers */
int primes[2*MAX_N+1]; /* array containing all needed primes */

/* Eratosthenes' sieve */
void sieve()
{
  int len=2*n;
  FOR(i,2,len) { prime[i]=1; factor[i]=i; }
  FOR(i,2,len) if (prime[i])
  {
    if (len/i<i) break;
    int j=sqr(i);
    while (j<=len) { prime[j]=0; factor[j]=i; j+=i; }
  }
  pr=0;
  FOR(i,2,len) if (prime[i])
  {
    prime[i]=++pr;
    primes[pr]=i;
  }
}

int tree[2*MAX_N+1],size; /* static binary tree */
int leaf[2*MAX_N+1]; /* exponents of primes that are in the tree leaves */
int cat[MAX_N+1];

void prepare_tree()
{
  size=1;
  while (size<=pr) size*=2;
  FOR(i,1,2*size-1) tree[i]=1; /* products of children */
}

/* Fast modular exponentiation. */
int expmod(int x,int n)
{
	ll a=1LL,b=x%m;
	while (n>0)
		if (n%2) { a=(a*b)%(ll)m; n--; }
		else { b=(b*b)%(ll)m; n/=2; }
	return (int)a;
}

inline void insert(int x,int diff)
{
  int v=size+x;
  leaf[v]+=diff;
  tree[v]=expmod(primes[x],leaf[v]);
  while (v!=1)
  {
    v/=2;
    tree[v]=int(((ll)tree[2*v]*tree[2*v+1])%(ll)m);
  }
}

/* Multiplies the result by x (diff=1) or divides it by 1 (diff=-1). */
void multiply(int x,int diff)
{
  while (x>1)
  {
    int v=factor[x];
    insert(prime[v],diff);
    x/=v;
  }
}

void doit()
{
  prepare_tree();
  ll sum=1LL;
  cat[3]=1;
  FOR(i,4,n)
  {
    /* from one Catalan number to another one */
    multiply(2,1);
    int nr=i-3;
    multiply(2*nr+1,1);
    multiply(nr+2,-1);
    cat[i]=tree[1];
    sum+=cat[i];
  }
  printf("%lld\n",sum%m);
}

int main()
{
  scanf("%d %d",&n,&m);
  sieve();
  doit();
  return 0;
}
